@@ -54,7 +54,10 @@ class DatagramProtocolImpl(DatagramProtocol):
             self.close_waiter.set_exception(exc)
 
     def datagram_received(self, data: bytes, addr: Address) -> None:
-        self._read_queue.put_nowait((data, addr))
+        try:
+            self._read_queue.put_nowait((data, addr))
+        except asyncio.QueueFull as error:
+            self.error_waiter.set_exception(error)
 
     def error_received(self, exc: Exception) -> None:
         self.error_waiter.set_exception(exc)
@@ -140,7 +143,7 @@ class DatagramServer(DatagramBase):
         """
         self._base.transport.sendto(data, addr)
 
-    async def read(self) -> Tuple[bytes, Address]:
+    async def recvfrom(self) -> Tuple[bytes, Address]:
         """Read a datagram
 
         Raises:
@@ -163,7 +166,7 @@ class DatagramClient(DatagramBase):
         """
         self._base.transport.sendto(data)
 
-    async def read(self) -> bytes:
+    async def recv(self) -> bytes:
         """Read a datagram
 
         Raises:
